@@ -1,7 +1,7 @@
 /* storage.c:  Code and data storage manipulations.  This includes labels. */
 
 /*  This file is part of bc written for MINIX.
-    Copyright (C) 1991, 1992 Free Software Foundation, Inc.
+    Copyright (C) 1991, 1992, 1993, 1994 Free Software Foundation, Inc.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -895,7 +895,6 @@ process_params (pc, func)
 {
   char ch;
   arg_list *params;
-  char warned = FALSE;
   int ix, ix1;
   bc_var *v_temp;
   bc_var_array *a_src, *a_dest;
@@ -954,11 +953,8 @@ process_params (pc, func)
 	}
       else
 	{
-	  if (!warned)
-	    {
-	      rt_error ("Parameter number mismatch");
-	      warned = TRUE;
-	    }
+	    rt_error ("Parameter number mismatch");
+	    return;
 	}
       params = params->next;
     }
